.. $Id: index.rst 1515 2014-03-11 06:05:15Z jemian $

==============================================
Documenting SPEC Macro Source Code with Sphinx
==============================================

.. include:: ../README

Contents
========

.. toctree::
   :maxdepth: 2

   howto
   examples
   conventions
   style_guide
   spec
   other
   references
